snntorch.spikeplot
-------------------------
:mod:`snntorch.spikeplot` is deeply integrated with `matplotlib.pyplot` and `celluloid`.
It serves to reduce the amount of boilerplate code required  to generate a variety of animations and plots.

.. automodule:: snntorch.spikeplot
   :members:
   :undoc-members:
   :show-inheritance:
